@@ -20,21 +20,21 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"auto"} --- }
-#' {Automatically computes appropriate correlations for
+#' \item \code{"auto"} --- Automatically computes appropriate correlations for
 #' the data using Pearson's for continuous, polychoric for ordinal,
 #' tetrachoric for binary, and polyserial/biserial for ordinal/binary with
 #' continuous. To change the number of categories that are considered
 #' ordinal, use \code{ordinal.categories}
-#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)}
+#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)
 #' 
-#' \item{\code{"pearson"} --- }
-#' {Pearson's correlation is computed for all variables regardless of
-#' categories}
+#' \item \code{"cor_auto"} --- Uses \code{\link[qgraph]{cor_auto}} to compute correlations. 
+#' Arguments can be passed along to the function
 #' 
-#' \item{\code{"spearman"} --- }
-#' {Spearman's rank-order correlation is computed for all variables
-#' regardless of categories}
+#' \item \code{"pearson"} --- Pearson's correlation is computed for all 
+#' variables regardless of categories
+#' 
+#' \item \code{"spearman"} --- Spearman's rank-order correlation is computed 
+#' for all variables regardless of categories
 #' 
 #' }
 #' 
@@ -48,12 +48,10 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"pairwise"} --- }
-#' {Computes correlation for all available cases between
-#' two variables}
+#' \item \code{"pairwise"} --- Computes correlation for all available cases between
+#' two variables
 #' 
-#' \item{\code{"listwise"} --- }
-#' {Computes correlation for all complete cases in the dataset}
+#' \item \code{"listwise"} --- Computes correlation for all complete cases in the dataset
 #' 
 #' }
 #' 
@@ -63,19 +61,16 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"BGGM"} --- }
-#' {Computes the Bayesian Gaussian Graphical Model.
+#' \item \code{"BGGM"} --- Computes the Bayesian Gaussian Graphical Model.
 #' Set argument \code{ordinal.categories} to determine
 #' levels allowed for a variable to be considered ordinal.
-#' See \code{\link[BGGM]{estimate}} for more details}
+#' See \code{?BGGM::estimate} for more details
 #' 
-#' \item{\code{"glasso"} --- }
-#' {Computes the GLASSO with EBIC model selection.
-#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details}
+#' \item \code{"glasso"} --- Computes the GLASSO with EBIC model selection.
+#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details
 #' 
-#' \item{\code{"TMFG"} --- }
-#' {Computes the TMFG method.
-#' See \code{\link[EGAnet]{TMFG}} for more details}
+#' \item \code{"TMFG"} --- Computes the TMFG method.
+#' See \code{\link[EGAnet]{TMFG}} for more details
 #' 
 #' }
 #' 
@@ -87,18 +82,15 @@
 #' 
 #' \itemize{
 #'
-#' \item{\code{"leiden"} --- }
-#' {See \code{\link[igraph]{cluster_leiden}} for more details}
+#' \item \code{"leiden"} --- See \code{\link[igraph]{cluster_leiden}} for more details
 #' 
-#' \item{\code{"louvain"} --- }
-#' {By default, \code{"louvain"} will implement the Louvain algorithm using 
+#' \item \code{"louvain"} --- By default, \code{"louvain"} will implement the Louvain algorithm using 
 #' the consensus clustering method (see \code{\link[EGAnet]{community.consensus}} 
 #' for more information). This function will implement
 #' \code{consensus.method = "most_common"} and \code{consensus.iter = 1000} 
-#' unless specified otherwise}
+#' unless specified otherwise
 #' 
-#' \item{\code{"walktrap"} --- }
-#' {See \code{\link[igraph]{cluster_walktrap}} for more details}
+#' \item \code{"walktrap"} --- See \code{\link[igraph]{cluster_walktrap}} for more details
 #' 
 #' }
 #'
@@ -109,28 +101,25 @@
 #' 
 #' \itemize{
 #'
-#' \item{\code{"expand"} --- }
-#' {Expands the correlation matrix with four variables correlated 0.50.
+#' \item \code{"expand"} --- Expands the correlation matrix with four variables correlated 0.50.
 #' If number of dimension returns 2 or less in check, then the data 
 #' are unidimensional; otherwise, regular EGA with no matrix
 #' expansion is used. This method was used in the Golino et al.'s (2020)
-#' \emph{Psychological Methods} simulation}
+#' \emph{Psychological Methods} simulation
 #'
-#' \item{\code{"LE"} --- }
-#' {Applies the Leading Eigenvector algorithm
+#' \item \code{"LE"} --- Applies the Leading Eigenvector algorithm
 #' (\code{\link[igraph]{cluster_leading_eigen}})
 #' on the empirical correlation matrix. If the number of dimensions is 1,
 #' then the Leading Eigenvector solution is used; otherwise, regular EGA
 #' is used. This method was used in the Christensen et al.'s (2023) 
-#' \emph{Behavior Research Methods} simulation}
+#' \emph{Behavior Research Methods} simulation
 #' 
-#' \item{\code{"louvain"} --- }
-#' {Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
+#' \item \code{"louvain"} --- Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
 #' on the empirical correlation matrix. If the number of dimensions is 1, 
 #' then the Louvain solution is used; otherwise, regular EGA is used. 
 #' This method was validated Christensen's (2022) \emph{PsyArXiv} simulation.
 #' Consensus clustering can be used by specifying either
-#' \code{"consensus.method"} or \code{"consensus.iter"}}
+#' \code{"consensus.method"} or \code{"consensus.iter"}
 #' 
 #' }
 #'
@@ -145,14 +134,12 @@
 #'
 #' \itemize{
 #'
-#' \item{\code{"parametric"} --- }
-#' {Generates \code{iter} new datasets from
+#' \item \code{"parametric"} --- Generates \code{iter} new datasets from
 #' (multivariate normal random distributions) based on the
-#' original dataset using \code{\link[MASS]{mvrnorm}}}
+#' original dataset using \code{\link[MASS]{mvrnorm}}
 #'
-#' \item{\code{"resampling"} --- }
-#' {Generates \code{iter} new datasets from random subsamples 
-#' of the original data}
+#' \item \code{"resampling"} --- Generates \code{iter} new datasets from random subsamples 
+#' of the original data
 #'
 #' }
 #' 
@@ -172,18 +159,14 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"\link[EGAnet]{EGA}"} --- }
-#' {Uses standard exploratory graph analysis}
+#' \item \code{"\link[EGAnet]{EGA}"} --- Uses standard exploratory graph analysis
 #' 
-#' \item{\code{"\link[EGAnet]{EGA.fit}"} --- }
-#' {Uses \code{\link[EGAnet]{tefi}} to determine best fit of
-#' \code{\link[EGAnet]{EGA}}}
+#' \item \code{"\link[EGAnet]{EGA.fit}"} --- Uses \code{\link[EGAnet]{tefi}} to determine best fit of
+#' \code{\link[EGAnet]{EGA}}
 #' 
-#' \item{\code{"\link[EGAnet]{hierEGA}"} --- }
-#' {Uses hierarhical exploratory graph analysis}
+#' \item \code{"\link[EGAnet]{hierEGA}"} --- Uses hierarchical exploratory graph analysis
 #' 
-#' \item{\code{"\link[EGAnet]{riEGA}"} --- }
-#' {Uses random-intercept exploratory graph analysis}
+#' \item \code{"\link[EGAnet]{riEGA}"} --- Uses random-intercept exploratory graph analysis
 #' 
 #' }
 #' 
@@ -266,14 +249,11 @@
 #'
 #' \itemize{
 #'
-#' \item{\code{graph} --- }
-#' {Network matrix of the median network structure}
+#' \item \code{graph} --- Network matrix of the median network structure
 #'
-#' \item{\code{typical.dim.variables} --- }
-#' {An ordered matrix of item allocation}
+#' \item \code{typical.dim.variables} --- An ordered matrix of item allocation
 #'
-#' \item{\code{wc} --- }
-#' {Membership assignments of the median network}
+#' \item \code{wc} --- Membership assignments of the median network
 #' 
 #' }
 #' 
@@ -343,10 +323,10 @@
 #' @export
 #'
 # Bootstrap EGA ----
-# Updated 09.08.2023
+# Updated 24.10.2023
 bootEGA <- function(
     data, n = NULL,
-    corr = c("auto", "pearson", "spearman"),
+    corr = c("auto", "cor_auto", "pearson", "spearman"),
     na.data = c("pairwise", "listwise"),
     model = c("BGGM", "glasso", "TMFG"),  
     algorithm = c("leiden", "louvain", "walktrap"),
@@ -363,11 +343,10 @@ bootEGA <- function(
   store_state()
   
   # Get ellipse arguments
-  ellipse <- list(...)
+  ellipse <- list(needs_usable = FALSE, ...)
   
   # Check for missing arguments (argument, default, function)
-  corr <- set_default(corr, "auto", c("auto", "cor_auto", "pearson", "spearman"))
-  corr <- swiftelse(corr == "cor_auto", "auto", corr) # deprecate `cor_auto`
+  corr <- set_default(corr, "auto", bootEGA)
   na.data <- set_default(na.data, "pairwise", auto.correlate)
   model <- set_default(model, "glasso", network.estimation)
   algorithm <- set_default(algorithm, "walktrap", community.detection)
@@ -381,7 +360,7 @@ bootEGA <- function(
   # Argument errors (return data in case of tibble)
   data <- bootEGA_errors(
     data, n, iter, ncores, typicalStructure,
-    plot.typicalStructure, seed, verbose
+    plot.typicalStructure, seed, verbose, ...
   )
   
   # `EGA.estimate` will handle legacy arguments and data processing 
@@ -603,10 +582,10 @@ bootEGA <- function(
 
 #' @noRd
 # Errors ----
-# Updated 19.08.2023
+# Updated 07.09.2023
 bootEGA_errors <- function(
     data, n, iter, ncores, typicalStructure,
-    plot.typicalStructure, seed, verbose
+    plot.typicalStructure, seed, verbose, ...
 )
 {
   
@@ -653,8 +632,13 @@ bootEGA_errors <- function(
   length_error(verbose, 1, "bootEGA")
   typeof_error(verbose, "logical", "bootEGA")
   
+  # Check for usable data
+  if(needs_usable(list(...))){
+    data <- usable_data(data, verbose)
+  }
+  
   # Return usable data (in case of tibble)
-  return(usable_data(data, verbose))
+  return(data)
   
 }
 
@@ -1360,10 +1344,15 @@ estimate_typical_EGA.fit <- function(results, ellipse)
   model <- tolower(model_attributes$model)
   algorithm <- tolower(algorithm_attributes$algorithm)
   
+  # Check for {BGGM}
+  if(model == "bggm"){
+    stop("Due to CRAN check issues, `model = \"BGGM\"` is not available at the moment.")
+  }
+  
   # Get network
   network <- switch(
     model,
-    "bggm" = symmetric_matrix_lapply(results$bootGraphs, median),
+    # "bggm" = symmetric_matrix_lapply(results$bootGraphs, median),
     "glasso" = symmetric_matrix_lapply(results$bootGraphs, median),
     "tmfg" = symmetric_matrix_lapply(results$bootGraphs, mean)
   )
@@ -1438,7 +1427,7 @@ estimate_typical_EGA.fit <- function(results, ellipse)
 
 #' @noRd
 # Typical network and memberships ----
-# Updated 31.07.2023
+# Updated 24.10.2023
 estimate_typicalStructure <- function(
     data, results, verbose, ...
 )
@@ -1467,13 +1456,18 @@ estimate_typicalStructure <- function(
   algorithm <- tolower(algorithm_attributes$algorithm)
   uni.method <- tolower(unidimensional_attributes$uni.method)
   
+  # Check for {BGGM}
+  if(model == "bggm"){
+    stop("Due to CRAN check issues, `model = \"BGGM\"` is not available at the moment.")
+  }
+  
   # Branch for hierarchical EGA
   if(results$EGA.type == "hierega"){
     
     # Get network
     network <- switch(
       model,
-      "bggm" = symmetric_matrix_lapply(results$lower_order$bootGraphs, median),
+      # "bggm" = symmetric_matrix_lapply(results$lower_order$bootGraphs, median),
       "glasso" = symmetric_matrix_lapply(results$lower_order$bootGraphs, median),
       "tmfg" = symmetric_matrix_lapply(results$lower_order$bootGraphs, mean)
     )
@@ -1483,7 +1477,7 @@ estimate_typicalStructure <- function(
     # Get network
     network <- switch(
       model,
-      "bggm" = symmetric_matrix_lapply(results$bootGraphs, median),
+      # "bggm" = symmetric_matrix_lapply(results$bootGraphs, median),
       "glasso" = symmetric_matrix_lapply(results$bootGraphs, median),
       "tmfg" = symmetric_matrix_lapply(results$bootGraphs, mean)
     )
@@ -1542,13 +1536,13 @@ estimate_typicalStructure <- function(
   # Obtain arguments for model
   model_ARGS <- switch(
     model,
-    "bggm" = c(
-      obtain_arguments(BGGM::estimate, model_attributes),
-      overwrite_arguments(
-        # defaults for `BGGM:::select.estimate`
-        list(cred = 0.95, alternative = "two.sided"), model_attributes
-      )
-    ),
+    # "bggm" = c(
+    #   obtain_arguments(BGGM::estimate, model_attributes),
+    #   overwrite_arguments(
+    #     # defaults for `BGGM:::select.estimate`
+    #     list(cred = 0.95, alternative = "two.sided"), model_attributes
+    #   )
+    # ),
     "glasso" = obtain_arguments(EBICglasso.qgraph, model_attributes),
     "tmfg" = obtain_arguments(TMFG, model_attributes)
   )
