@@ -242,21 +242,28 @@ reproducible_seeds <- function(n, seed = NULL)
 
 #' @noRd
 # Generate uniform data ----
-# Always between 0 and 1
-# Updated 30.07.2023
-runif_xoshiro <- function(n, seed = NULL)
+# Allows adjustment of range
+# Updated 26.10.2023
+runif_xoshiro <- function(n, min = 0, max = 1, seed = NULL)
 {
   
-  # Return call from C
-  return(
-    .Call(
-      "r_xoshiro_uniform",
-      as.integer(n),
-      swiftelse(is.null(seed), 0, seed),
-      PACKAGE = "EGAnet"
-    )
+  # Get values
+  values <- .Call(
+    "r_xoshiro_uniform",
+    as.integer(n),
+    swiftelse(is.null(seed), 0, seed),
+    PACKAGE = "EGAnet"
   )
   
+  # Check for changes to minimum and maximum
+  if(min != 0 || max != 1){ # transform
+    values <- min + (max - min) * values
+  }
+  
+  
+  # Return call from C
+  return(values)
+  
 }
 
 #' @noRd
@@ -441,6 +448,16 @@ reproducible_bootstrap <- function(
 # PARALLELIZATION ----
 #%%%%%%%%%%%%%%%%%%%%%
 
+#' @noRd
+# Clear memory ----
+# Updated 07.11.2023
+clear_memory <- function()
+{
+  sink <- capture.output(
+    gc(verbose = FALSE, reset = TRUE, full = TRUE)
+  )
+}
+
 #' @noRd
 # Get available memory ----
 # Updated 18.10.2023
@@ -761,6 +778,15 @@ swiftelse <- function(condition, true, false)
 # FORMATTING FUNCTIONS ----
 #%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+#' @noRd
+# Determine decimal places before non-zero ----
+# From StackOverflow: https://stackoverflow.com/questions/35553244/count-leading-zeros-between-the-decimal-point-and-first-nonzero-digit
+# Updated 10.11.2023
+leading_zero <- function(number)
+{
+  floor(-log10(.Machine$double.eps + abs(number) - floor(abs(number))))
+}
+
 #' @noRd
 # Determine number of digits in a number ----
 # Updated 24.07.2023
@@ -1732,14 +1758,14 @@ legacy_EGA_args <- function(ellipse)
 
 #' @noRd
 # Make unidimensional CFA model ----
-# Updated 25.07.2023
+# Updated 08.11.2023
 make_unidimensional_cfa <- function(variable_names)
 {
   return(
     paste(
       "LF =~",
       swiftelse(
-        length(variable_names == 2),
+        length(variable_names) == 2,
         paste0("a*", variable_names, collapse = " + "),
         paste(variable_names, collapse = " + ")
       )
@@ -2442,7 +2468,7 @@ dimension_comparison <- function(original, comparison){
 
 #' @noRd
 # Basic set up for comparing plots ----
-# Updated 28.09.2023
+# Updated 26.10.2023
 compare_plots <- function(comparison_network, comparison_wc, plot_ARGS)
 {
   
@@ -2477,20 +2503,25 @@ compare_plots <- function(comparison_network, comparison_wc, plot_ARGS)
   ## Essentially, the same call but allows some freedom
   plot_ARGS[c("net", "node.color")] <- NULL
   
-  ## Check for "edge" stuff
-  edge_stuff <- c(
-    "edge.alpha", "edge.color", 
-    "edge.lty", "edge.size"
-  )
+  # Check for edges
+  ## Assume more than one edge alpha is default
+  if(length(plot_ARGS[["edge.alpha"]]) > 1){
+    plot_ARGS[["edge.alpha"]] <- NULL
+  }
   
-  ## Check for lengths of "edge" stuff
-  edge_lengths <- edge_stuff[
-    nvapply(plot_ARGS[edge_stuff], length) > 1
-  ]
+  ## Assume more than two edge color is default
+  if(length(plot_ARGS[["edge.color"]]) > 2){
+    plot_ARGS[["edge.color"]] <- NULL
+  }
   
-  ## Get edges arguments
-  if(length(edge_lengths) != 0){
-    plot_ARGS[edge_lengths] <- NULL
+  ## Assume more than two edge line type is default
+  if(length(plot_ARGS[["edge.lty"]]) > 2){
+    plot_ARGS[["edge.lty"]] <- NULL
+  }
+  
+  ## Assume more than one edge size is default
+  if(length(plot_ARGS[["edge.size"]]) > 1){
+    plot_ARGS[["edge.size"]] <- NULL
   }
   
   # Send on and return from `basic_plot_setup`
@@ -2747,65 +2778,129 @@ pcor2inv <- function(partial_correlations)
 #%%%%%%%%%%%%%%%%%%%%%%%%
 
 #' @noRd
-# Rewire networks ----
-# About 10x faster than previous implementation
-# Updated 30.07.2023
-rewire <- function(
-    network, min = 0.20, max = 0.40,
-    noise = 0.10, lower_triangle
-)
+# Create sparse network ----
+# Updated 08.11.2023
+sparse_network <- function(network)
 {
   
-  # Work only with the lower triangle
-  lower_network <- network[lower_triangle]
+  # Get number of nodes
+  nodes <- dim(network)[2]
   
-  # Get non-zero edges
-  non_zero_edges <- which(lower_network != 0)
+  # Get node sequence
+  node_sequence <- seq_len(nodes)
   
-  # Number of edges
-  edges <- length(non_zero_edges)
+  # Create data frame
+  sparse_df <- data.frame(
+    row = rep(node_sequence, each = nodes),
+    col = rep(node_sequence, times = nodes),
+    weight = as.vector(network)
+  )
   
-  # Add noise
-  if(!is.null(noise)){
+  # Return lower triangle
+  return(sparse_df[sparse_df$row < sparse_df$col,])
+  
+}
+
+#' @noRd
+# Scramble networks ----
+# Updated 11.11.2023
+network_scramble <- function(base, comparison)
+{
+  
+  # Get sparse networks
+  base_sparse <- sparse_network(base)
+  comparison_sparse <- sparse_network(comparison)
+  
+  # Get edges
+  base_edges <- base_sparse$weight != 0
+  comparison_edges <- comparison_sparse$weight != 0
+  
+  # Get shared edges
+  shared_total <- sum(base_edges & comparison_edges)
+  
+  # Get unique indices in comparison
+  unique_index <- !base_edges & comparison_edges
+  
+  # Assign edges
+  base_sparse$weight[-shuffle(which(base_edges), shared_total)] <- 0
+  base_sparse$weight[unique_index] <- comparison_sparse$weight[unique_index]
+  
+  # Remove zero edges from equivalent
+  base_sparse <- base_sparse[base_sparse$weight != 0,]
+  
+  # Get number of nodes
+  nodes <- dim(base)[2]
+  
+  # Initialize network to return
+  return_network <- matrix(0, nrow = nodes, ncol = nodes)
+  
+  # Loop over sparse equivalent
+  for(i in nrow_sequence(base_sparse)){
     
-    # Only add to existing edges
-    lower_network[non_zero_edges] <- 
-      lower_network[non_zero_edges] + runif(edges, -noise, noise)
+    # Populate return network
+    return_network[base_sparse$row[i], base_sparse$col[i]] <-
+    return_network[base_sparse$col[i], base_sparse$row[i]] <-
+    base_sparse$weight[i]
     
   }
   
-  # Number of edges to rewire
-  rewire_edges <- floor(edges * runif(1, min, max))
+  # Return the network
+  return(return_network)
   
-  # Get rewiring indices
-  rewire_index <- shuffle(non_zero_edges, size = rewire_edges)
+}
+
+#' @noRd
+# Rewiring based on {igraph} ----
+# Updated 30.10.2023
+igraph_rewire <- function(network, prob, noise = 0)
+{
   
-  # Get replacement indices
-  replace_index <- shuffle(seq_along(lower_network), size = rewire_edges)
-  
-  # Make a copy of the lower network
-  lower_network_original <- lower_network
-  
-  # Replace values
-  lower_network[rewire_index] <- lower_network_original[replace_index]
-  lower_network[replace_index] <- lower_network_original[rewire_index]
-  
-  # Get nodes in original network
+  # Get nodes
   nodes <- dim(network)[2]
   
-  # Initialize a new network
-  new_network <- matrix(
-    0, nrow = nodes, ncol = nodes,
-    dimnames = dimnames(network)
+  # Assume NAs are zero
+  network[is.na(network)] <- 0
+  
+  # Get rewired network
+  rewired_network <- igraph2matrix(
+    igraph::rewire(
+      graph = convert2igraph(network),
+      with = igraph::each_edge(prob = prob)
+    )
   )
   
-  # Replace values
-  new_network[lower_triangle] <- lower_network
-  new_network <- t(new_network)
-  new_network[lower_triangle] <- lower_network
+  # Add noise (if any)
+  if(noise != 0){
+    
+    # Get absolute noise
+    abs_noise <- abs(noise)
+    
+    # Get lower triangle
+    lower_triangle <- lower.tri(rewired_network)
+    
+    # Get lower triangle
+    rewired_lower <- rewired_network[lower_triangle]
+    
+    # Get non-zero
+    non_zero <- rewired_lower != 0
+    
+    # Set noise
+    rewired_lower[non_zero] <- rewired_lower[non_zero] +
+      runif_xoshiro(sum(non_zero), min = -abs_noise, max = abs_noise)
+    
+    # Create new matrix
+    rewired_network <- matrix(0, nrow = nodes, ncol = nodes)
+    
+    # Add to lower triangle
+    rewired_network[lower_triangle] <- rewired_lower
+    
+    # Make symmetric
+    rewired_network <- rewired_network + t(rewired_network)
+    
+  }
   
-  # Return the rewired network
-  return(new_network)
+  # Return rewired network
+  return(rewired_network)
   
 }
 
