@@ -161,7 +161,7 @@ tefi_errors <- function(data, verbose)
 
 #' @noRd
 # Handle structure input ----
-# Updated 13.08.2023
+# Updated 06.10.2023
 get_tefi_structure <- function(data, structure, ega_object = NULL)
 {
   
@@ -228,7 +228,7 @@ get_tefi_structure <- function(data, structure, ega_object = NULL)
     # Get flag for hierarchical
     if(is(data, "hierEGA")){ # Use internal `hierEGA_structure` from `itemStability`
       structure <- hierEGA_structure(ega_object, structure)
-    }else if(is.null(structure)){
+    }else if(is.null(structure)){ # Use EGA memberships
       structure <- ega_object$wc
     }else{ # Ensure proper length
       length_error(structure, length(ega_object$wc), "tefi")
@@ -236,6 +236,27 @@ get_tefi_structure <- function(data, structure, ega_object = NULL)
 
   }
   
+  # Convert if string
+  if(is.list(structure)){
+    
+    # Check for characters
+    structure <- lapply(
+      structure, function(x){
+        
+        # If characters, then convert to numeric
+        swiftelse(
+          is.character(x),
+          as.numeric(reindex_memberships(x)),
+          x
+        )
+        
+      }
+    )
+    
+  }else if(is.character(structure)){
+    structure <- as.numeric(reindex_memberships(structure))
+  }
+  
   # Return structure
   return(structure)
 
